@@ -9,7 +9,7 @@ import (
 )
 
 const (
-	version = "0.17.0"
+	version = "0.18.0"
 )
 
 func main() {
@@ -45,6 +45,9 @@ func main() {
 	} else if *flagDebug {
 		log.SetLevel(log.DebugLevel)
 	}
+	flag.VisitAll(func(f *flag.Flag) {
+		log.Infof("flag: %s: %s", f.Name, f.Value)
+	})
 	d := ovs.NewDriver(
 		*flagFaucetconfrpcClientName,
 		*flagFaucetconfrpcServerName,
